@@ -26,17 +26,18 @@
 
 static int usage(void)
 {
-	fprintf(stderr, "Usage: ip netns list\n");
-	fprintf(stderr, "       ip netns add NAME\n");
-	fprintf(stderr, "       ip netns attach NAME PID\n");
-	fprintf(stderr, "       ip netns set NAME NETNSID\n");
-	fprintf(stderr, "       ip [-all] netns delete [NAME]\n");
-	fprintf(stderr, "       ip netns identify [PID]\n");
-	fprintf(stderr, "       ip netns pids NAME\n");
-	fprintf(stderr, "       ip [-all] netns exec [NAME] cmd ...\n");
-	fprintf(stderr, "       ip netns monitor\n");
-	fprintf(stderr, "       ip netns list-id\n");
-	fprintf(stderr, "NETNSID := auto | POSITIVE-INT\n");
+	fprintf(stderr,
+		"Usage:	ip netns list\n"
+		"	ip netns add NAME\n"
+		"	ip netns attach NAME PID\n"
+		"	ip netns set NAME NETNSID\n"
+		"	ip [-all] netns delete [NAME]\n"
+		"	ip netns identify [PID]\n"
+		"	ip netns pids NAME\n"
+		"	ip [-all] netns exec [NAME] cmd ...\n"
+		"	ip netns monitor\n"
+		"	ip netns list-id\n"
+		"NETNSID := auto | POSITIVE-INT\n");
 	exit(-1);
 }
 
